@@ -1,7 +1,7 @@
 /*
  * FigTreeApplication.java
  *
- * Copyright (C) 2012 Andrew Rambaut
+ * Copyright (C) 2006-2014 Andrew Rambaut
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,27 +25,27 @@
  * Description:		An application for analysing MCMC trace files.
  * @author			Andrew Rambaut
  * @author			Alexei Drummond
- * @version			$Id: FigTreeApplication.java,v 1.15 2007/09/10 14:52:02 rambaut Exp $
+ * @version			$Id$
  */
 
 package figtree.application;
 
+import com.itextpdf.text.Document;
+import com.itextpdf.text.DocumentException;
+import com.itextpdf.text.pdf.PdfContentByte;
+import com.itextpdf.text.pdf.PdfTemplate;
+import com.itextpdf.text.pdf.PdfWriter;
 import figtree.application.preferences.*;
 import figtree.treeviewer.ExtendedTreeViewer;
 import jam.framework.*;
 import jam.controlpalettes.BasicControlPalette;
 import jam.controlpalettes.ControlPalette;
 import jam.mac.Utils;
-import org.freehep.graphics2d.VectorGraphics;
-import org.freehep.graphicsio.ps.PSGraphics2D;
-import org.freehep.graphicsio.pdf.PDFGraphics2D;
-import org.freehep.graphicsio.emf.EMFGraphics2D;
-import org.freehep.graphicsio.svg.SVGGraphics2D;
-import org.freehep.graphicsio.gif.GIFGraphics2D;
-import org.freehep.graphicsio.swf.SWFGraphics2D;
 
 import java.awt.*;
+import java.awt.image.BufferedImage;
 import java.io.*;
+import java.net.URL;
 import java.util.*;
 import java.util.List;
 
@@ -53,21 +53,38 @@ import jebl.evolution.io.ImportException;
 import jebl.evolution.io.NewickImporter;
 import jebl.evolution.trees.Tree;
 
+import javax.imageio.ImageIO;
 import javax.swing.*;
 
 import ch.randelshofer.quaqua.QuaquaManager;
+import org.apache.batik.dom.GenericDOMImplementation;
+import org.apache.batik.svggen.SVGGraphics2D;
+import org.w3c.dom.DOMImplementation;
 
+/**
+ * Application class for FigTree including main() method for invoking it.
+ * Uses JAM Application classes to create a MultiDoc Application.
+ *
+ * @author Andrew Rambaut
+ * @version $Id$
+ *
+ * $HeadURL$
+ *
+ * $LastChangedBy$
+ * $LastChangedDate$
+ * $LastChangedRevision$
+ */
 public class FigTreeApplication extends MultiDocApplication {
 
-    public static final String VERSION = "1.4.1";
-    public static final String DATES = "2006-2013";
+    public static final String VERSION = "1.4.3";
+    public static final String DATES = "2006-2016";
 
     public static FigTreeApplication application;
 
-    public FigTreeApplication(MenuBarFactory menuBarFactory, String nameString, String aboutString, Icon icon,
+    public FigTreeApplication(MenuBarFactory menuBarFactory, String nameString,  String titleString, String aboutString, Icon icon,
                               String websiteURLString,
                               String helpURLString) {
-        super(menuBarFactory, nameString, aboutString, icon, websiteURLString, helpURLString);
+        super(menuBarFactory, nameString, titleString, aboutString, icon, websiteURLString, helpURLString);
 
 //        addPreferencesSection(new GeneralPreferencesSection());
         addPreferencesSection(new AppearancePreferencesSection());
@@ -153,57 +170,33 @@ public class FigTreeApplication extends MultiDocApplication {
                 stream = System.out;
             }
 
-            Properties p = new Properties();
-//	        p.setProperty("PageSize","A5");
-            VectorGraphics g;
-
+            GraphicFormat format = null;
             if (graphicFormat.equals("PDF")) {
-                if (graphicFileName != null) {
-                    System.out.println("Creating PDF graphic: " + graphicFileName);
-                }
-                g = new PDFGraphics2D(stream, new Dimension(width, height));
-            } else if (graphicFormat.equals("PS")) {
-                if (graphicFileName != null) {
-                    System.out.println("Creating PS graphic: " + graphicFileName);
-                }
-                g = new PSGraphics2D(stream, new Dimension(width, height));
-            } else if (graphicFormat.equals("EMF")) {
-                if (graphicFileName != null) {
-                    System.out.println("Creating EMF graphic: " + graphicFileName);
-                }
-                g = new EMFGraphics2D(stream, new Dimension(width, height));
+                format = GraphicFormat.PDF;
             } else if (graphicFormat.equals("SVG")) {
-                if (graphicFileName != null) {
-                    System.out.println("Creating SVG graphic: " + graphicFileName);
-                }
-                g = new SVGGraphics2D(stream, new Dimension(width, height));
-            } else if (graphicFormat.equals("SWF")) {
-                if (graphicFileName != null) {
-                    System.out.println("Creating SWF graphic: " + graphicFileName);
-                }
-                g = new SWFGraphics2D(stream, new Dimension(width, height));
+                format = GraphicFormat.SVG;
             } else if (graphicFormat.equals("GIF")) {
-                if (graphicFileName != null) {
-                    System.out.println("Creating GIF graphic: " + graphicFileName);
-                }
-                g = new GIFGraphics2D(stream, new Dimension(width, height));
-//	        } else if (graphicFormat.equals("PNG")) {
-//		        g = new PNGGraphics2D(file, new Dimension(width, height));
-//	        } else if (graphicFormat.equals("JPEG")) {
-//		        g = new JPEGGraphics2D(file, new Dimension(width, height));
+                format = GraphicFormat.GIF;
+            } else if (graphicFormat.equals("PNG")) {
+                format = GraphicFormat.PNG;
+            } else if (graphicFormat.equals("JPEG")) {
+                format = GraphicFormat.JPEG;
             } else {
                 throw new RuntimeException("Unknown graphic format");
             }
 
-            g.setProperties(p);
-            g.startExport();
-            treeViewer.getContentPane().print(g);
-            g.endExport();
+            if (graphicFileName != null) {
+                System.out.println("Creating " + graphicFormat + " graphic: " + graphicFileName);
+            }
+
+            FigTreeFrame.exportGraphics(format, treeViewer.getContentPane(), stream);
 
         } catch(ImportException ie) {
-            throw new RuntimeException("Error writing graphic file: " + ie);
+            throw new RuntimeException("Error writing graphic file: " + ie.getMessage());
         } catch(IOException ioe) {
-            throw new RuntimeException("Error writing graphic file: " + ioe);
+            throw new RuntimeException("Error writing graphic file: " + ioe.getMessage());
+        } catch (DocumentException de) {
+            throw new RuntimeException("Error writing graphic file: " + de.getMessage());
         }
 
     }
@@ -226,8 +219,8 @@ public class FigTreeApplication extends MultiDocApplication {
         centreLine("a.rambaut@ed.ac.uk", 60);
         System.out.println();
         centreLine("http://tree.bio.ed.ac.uk/", 60);
-        centreLine("Uses the Java Evolutionary Biology Library (JEBL)", 60);
-        centreLine("http://jebl.sourceforge.net/", 60);
+        centreLine("Uses the Java Evolutionary Biology 2 Library (JEBL2)", 60);
+        centreLine("http://jebl2.googlecode.com/", 60);
         centreLine("Thanks to Alexei Drummond, Joseph Heled, Philippe Lemey, ", 60);
         centreLine("Tulio de Oliveira, Oliver Pybus, Beth Shapiro & Marc Suchard", 60);
         System.out.println();
@@ -248,16 +241,23 @@ public class FigTreeApplication extends MultiDocApplication {
     // Main entry point
     static public void main(String[] args) {
 
+        // There is a major issue with languages that use the comma as a decimal separator.
+        // To ensure compatibility between programs in the package, enforce the US locale.
+        //Locale.setDefault(Locale.US);
+
         Arguments arguments = new Arguments(
                 new Arguments.Option[] {
                         new Arguments.StringOption("graphic", new String[] {
-                                "PDF", "SVG", "SWF", "PS", "EMF",
-                                // "PNG",
-                                "GIF",
-                                // "JPEG"
+                                "PDF",
+                                "SVG",
+                                // "SWF", "PS", "EMF",
+                                "PNG",
+                                // "GIF",
+                                "JPEG"
                         }, false, "produce a graphic with the given format"),
                         new Arguments.IntegerOption("width", "the width of the graphic in pixels"),
                         new Arguments.IntegerOption("height", "the height of the graphic in pixels"),
+                        new Arguments.Option("url", "the input file is a URL"),
                         new Arguments.Option("help", "option to print this message")
                 });
 
@@ -361,12 +361,18 @@ public class FigTreeApplication extends MultiDocApplication {
         }
 
         if (!lafLoaded) {
+            UIManager.LookAndFeelInfo[] lafs = UIManager.getInstalledLookAndFeels();
+            for (UIManager.LookAndFeelInfo laf : lafs) {
+                System.out.println(laf);
+            }
+
             try {
                 // set the System Look and Feel in the UIManager
                 javax.swing.SwingUtilities.invokeAndWait(new Runnable() {
                     public void run() {
                         try {
                             UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
+//                              UIManager.setLookAndFeel(UIManager.getCrossPlatformLookAndFeelClassName());
                         } catch (Exception e) {
                             e.printStackTrace();
                         }
@@ -385,17 +391,28 @@ public class FigTreeApplication extends MultiDocApplication {
         }
 
         final String nameString = "FigTree";
-        String aboutString = "<html><center>Tree Figure Drawing Tool<br>Version " + VERSION + "<br>" + DATES + ", Andrew Rambaut<br>" +
-                "Institute of Evolutionary Biology, University of Edinburgh.<br><br>" +
+        String titleString = "<html>" +
+                "<div style=\"font-family:'Helvetica Neue', Helvetica, Arial, 'Lucida Grande',sans-serif\">" +
+                "<p style=\"font-weight: 100; font-size: 36px\">FigTree</p>" +
+                "<p style=\"font-weight: 200; font-size: 14px\">Tree Figure Drawing Tool</p>" +
+                "<p style=\"font-weight: 300; font-size: 12px\">Version " + VERSION + "</p>" +
+                "</div></html>";
+        String aboutString = "<html>" +
+                "<div style=\"font-family:'Helvetica Neue', Helvetica, Arial, 'Lucida Grande',sans-serif\">" +
+                "<center>"+ DATES + ", Andrew Rambaut<br>" +
+                "Institute of Evolutionary Biology, University of Edinburgh.<br>" +
                 "<a href=\"http://tree.bio.ed.ac.uk/\">http://tree.bio.ed.ac.uk/</a><br><br>" +
-                "Uses the Java Evolutionary Biology Library (JEBL)<br>" +
-                "<a href=\"http://sourceforge.net/projects/jebl/\">http://jebl.sourceforge.net/</a><br><br>" +
-                "Thanks to Alexei Drummond, Joseph Heled, Philippe Lemey, <br>Tulio de Oliveira, Oliver Pybus, Beth Shapiro & Marc Suchard</center></html>";
+                "Source code available from:<br>" +
+                "<a href=\"https://figtree.googlecode.com/\">http://figtree.googlecode.com/</a><br><br>" +
+                "Uses the Java Evolutionary Biology 2 Library (JEBL2)<br>" +
+                "<a href=\"https://jebl2.googlecode.com/\">http://jebl2.googlecode.com/</a><br><br>" +
+                "Thanks to Alexei Drummond, Joseph Heled, Philippe Lemey, <br>Tulio de Oliveira, Oliver Pybus, Beth Shapiro & Marc Suchard</center>" +
+                "</div></html>";
 
         String websiteURLString = "http://tree.bio.ed.ac.uk/software/figtree/";
         String helpURLString = "http://tree.bio.ed.ac.uk/software/figtree/";
 
-        FigTreeApplication.application = new FigTreeApplication(new FigTreeMenuBarFactory(), nameString, aboutString, icon,
+        FigTreeApplication.application = new FigTreeApplication(new FigTreeMenuBarFactory(), nameString, titleString, aboutString, icon,
                 websiteURLString, helpURLString);
 
         application.setDocumentFrameFactory(new DocumentFrameFactory() {
@@ -406,9 +423,19 @@ public class FigTreeApplication extends MultiDocApplication {
 
         application.initialize();
 
-        if (args.length > 0) {
-            for (String arg : args) {
-                application.doOpen(arg);
+        boolean useURLs = arguments.hasOption("url");
+        String[] leftoverArguments = arguments.getLeftoverArguments();
+        if (leftoverArguments.length > 0) {
+            for (String arg : leftoverArguments) {
+                if (useURLs) {
+                    FigTreeFrame frame = (FigTreeFrame)application.doNew();
+                    try {
+                        frame.readFromURL(new URL(arg));
+                    } catch (IOException e) {
+                    }
+                } else {
+                    application.doOpen(arg);
+                }
             }
         }
 
