@@ -1,3 +1,23 @@
+/*
+ * TreeAppearanceController.java
+ *
+ * Copyright (C) 2006-2014 Andrew Rambaut
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
+
 package figtree.treeviewer;
 
 import figtree.treeviewer.painters.AttributeComboHelper;
@@ -16,10 +36,17 @@ import java.util.*;
 import java.util.prefs.Preferences;
 
 import figtree.treeviewer.decorators.*;
+import jebl.evolution.trees.RootedTree;
 
 /**
  * @author Andrew Rambaut
- * @version $Id: TreeAppearanceController.java 822 2007-10-26 13:50:26Z rambaut $
+ * @version $Id$
+ *
+ * $HeadURL$
+ *
+ * $LastChangedBy$
+ * $LastChangedDate$
+ * $LastChangedRevision$
  */
 public class TreeAppearanceController extends AbstractController {
 
@@ -33,6 +60,8 @@ public class TreeAppearanceController extends AbstractController {
     public static final String BACKGROUND_COLOUR_KEY = "backgroundColour";
     public static final String SELECTION_COLOUR_KEY = "selectionColour";
     public static final String BRANCH_COLOR_ATTRIBUTE_KEY = "branchColorAttribute";
+    public static final String BRANCH_COLOR_GRADIENT_KEY = "branchColorGradient";
+    public static final String HILIGHTING_GRADIENT_KEY = "hilightingGradient";
     public static final String BACKGROUND_COLOR_ATTRIBUTE_KEY = "backgroundColorAttribute";
     public static final String BRANCH_LINE_WIDTH_KEY = "branchLineWidth";
     public static final String BRANCH_MIN_LINE_WIDTH_KEY = "branchMinLineWidth";
@@ -83,7 +112,7 @@ public class TreeAppearanceController extends AbstractController {
 //        branchColourSettings.toColour = new Color(192, 16, 0);
 //        branchColourSettings.middleColour = new Color(0, 0, 0);
 
-        branchColourIsGradient = false;
+        branchColourIsGradient = TreeAppearanceController.PREFS.getBoolean(CONTROLLER_KEY + "." + BRANCH_COLOR_GRADIENT_KEY, false);
 
         final JButton setupColourButton = new JButton("Colours");
 
@@ -95,16 +124,28 @@ public class TreeAppearanceController extends AbstractController {
             }
         });
 
-        final JCheckBox useGradientCheck = new JCheckBox("Gradient");
-        useGradientCheck.addChangeListener(new ChangeListener() {
+        branchColourGradientCheck = new JCheckBox("Gradient");
+        branchColourGradientCheck.addChangeListener(new ChangeListener() {
             public void stateChanged(ChangeEvent changeEvent) {
-                branchColourIsGradient = useGradientCheck.isSelected();
+                branchColourIsGradient = branchColourGradientCheck.isSelected();
                 setupBranchDecorators();
             }
         });
         optionsPanel.addComponentWithLabel("Colour by:", branchColourAttributeCombo);
         final JLabel setupColourButtonLabel = optionsPanel.addComponentWithLabel("Setup:", setupColourButton);
-        optionsPanel.addComponent(useGradientCheck);
+        optionsPanel.addComponent(branchColourGradientCheck);
+        optionsPanel.addSeparator();
+
+        boolean hilightingGradient = TreeAppearanceController.PREFS.getBoolean(CONTROLLER_KEY + "." + HILIGHTING_GRADIENT_KEY, false);
+
+        hilightingGradientCheck = new JCheckBox("Hilight with gradient");
+        hilightingGradientCheck.addChangeListener(new ChangeListener() {
+            public void stateChanged(ChangeEvent changeEvent) {
+                treeViewer.setHilightingGradient(hilightingGradientCheck.isSelected());
+            }
+        });
+        optionsPanel.addComponent(hilightingGradientCheck);
+        hilightingGradientCheck.setSelected(hilightingGradient);
         optionsPanel.addSeparator();
 
         branchLineWidthSpinner = new JSpinner(new SpinnerNumberModel(1.0, 0.01, 48.0, 1.0));
@@ -186,7 +227,8 @@ public class TreeAppearanceController extends AbstractController {
     private void setupBranchDecorators() {
 
         Decorator colourDecorator = colourController.getColourDecorator(branchColourAttributeCombo, userBranchColourDecorator);
-
+//        DiversityContinuousColourDecorator colourDecorator = new DiversityContinuousColourDecorator();
+//        colourDecorator.setTree((RootedTree)treeViewer.getCurrentTree());
 
 //                if (colourDecorator == null) {
 //                    if (attribute.endsWith("*")) {
@@ -224,11 +266,11 @@ public class TreeAppearanceController extends AbstractController {
 
         treeViewer.setBranchDecorator(compoundDecorator, branchColourIsGradient);
 
-        colourDecorator = null;
+        Decorator backgroundDecorator = null;
         if (backgroundColourAttributeCombo.getSelectedIndex() > 1) {
-            colourDecorator = colourController.getColourDecorator(backgroundColourAttributeCombo, null);
+            backgroundDecorator = colourController.getColourDecorator(backgroundColourAttributeCombo, null);
         }
-        treeViewer.setNodeBackgroundDecorator(colourDecorator);
+        treeViewer.setNodeBackgroundDecorator(backgroundDecorator);
 
     }
 
@@ -256,6 +298,8 @@ public class TreeAppearanceController extends AbstractController {
         treeViewer.setSelectionColor((Color)settings.get(CONTROLLER_KEY + "." + SELECTION_COLOUR_KEY));
 
         branchColourAttributeCombo.setSelectedItem(settings.get(CONTROLLER_KEY+"."+BRANCH_COLOR_ATTRIBUTE_KEY));
+        branchColourGradientCheck.setSelected((Boolean)settings.get(CONTROLLER_KEY+"."+BRANCH_COLOR_GRADIENT_KEY));
+        hilightingGradientCheck.setSelected((Boolean)settings.get(CONTROLLER_KEY+"."+HILIGHTING_GRADIENT_KEY));
         backgroundColourAttributeCombo.setSelectedItem(settings.get(CONTROLLER_KEY + "." + BACKGROUND_COLOR_ATTRIBUTE_KEY));
         branchLineWidthSpinner.setValue((Double) settings.get(CONTROLLER_KEY + "." + BRANCH_LINE_WIDTH_KEY));
         branchWidthAttributeCombo.setSelectedItem(settings.get(CONTROLLER_KEY+"."+BRANCH_WIDTH_ATTRIBUTE_KEY));
@@ -269,6 +313,8 @@ public class TreeAppearanceController extends AbstractController {
         settings.put(CONTROLLER_KEY + "." + SELECTION_COLOUR_KEY, treeViewer.getSelectionPaint());
 
         settings.put(CONTROLLER_KEY + "." + BRANCH_COLOR_ATTRIBUTE_KEY, branchColourAttributeCombo.getSelectedItem().toString());
+        settings.put(CONTROLLER_KEY + "." + BRANCH_COLOR_GRADIENT_KEY, branchColourGradientCheck.isSelected());
+        settings.put(CONTROLLER_KEY + "." + HILIGHTING_GRADIENT_KEY, hilightingGradientCheck.isSelected());
         settings.put(CONTROLLER_KEY + "." + BACKGROUND_COLOR_ATTRIBUTE_KEY, backgroundColourAttributeCombo.getSelectedItem().toString());
         settings.put(CONTROLLER_KEY + "." + BRANCH_LINE_WIDTH_KEY, branchLineWidthSpinner.getValue());
         settings.put(CONTROLLER_KEY + "." + BRANCH_WIDTH_ATTRIBUTE_KEY, branchWidthAttributeCombo.getSelectedItem().toString());
@@ -283,6 +329,8 @@ public class TreeAppearanceController extends AbstractController {
     private final OptionsPanel optionsPanel;
 
     private final JComboBox branchColourAttributeCombo;
+    private final JCheckBox branchColourGradientCheck;
+    private final JCheckBox hilightingGradientCheck;
     private final JComboBox backgroundColourAttributeCombo;
     private final JSpinner branchLineWidthSpinner;
     private final JSpinner branchMinLineWidthSpinner;
