@@ -1,7 +1,7 @@
 /*
  * NodeShapePainter.java
  *
- * Copyright (C) 2012 Andrew Rambaut
+ * Copyright (C) 2006-2014 Andrew Rambaut
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,7 +30,13 @@ import java.awt.geom.*;
 
 /**
  * @author Andrew Rambaut
- * @version $Id: NodeShapePainter.java 536 2006-11-21 16:10:24Z rambaut $
+ * @version $Id$
+ *
+ * $HeadURL$
+ *
+ * $LastChangedBy$
+ * $LastChangedDate$
+ * $LastChangedRevision$
  */
 public class NodeShapePainter extends NodePainter {
 
@@ -111,6 +117,20 @@ public class NodeShapePainter extends NodePainter {
         firePainterChanged();
     }
 
+    public void setNodeType(boolean external, boolean internal) {
+        this.external = external;
+        this.internal = internal;
+        firePainterChanged();
+    }
+
+    public boolean isExternal() {
+        return external;
+    }
+
+    public boolean isInternal() {
+        return internal;
+    }
+
     public double getPreferredWidth() {
         return 1.0;
     }
@@ -141,9 +161,11 @@ public class NodeShapePainter extends NodePainter {
         g2.setPaint(paint);
         g2.fill(nodeShape);
 
-        g2.setPaint(Color.black);
-        g2.setStroke(new BasicStroke(0.5F));
-        g2.draw(nodeShape);
+        if (outlineStroke > 0.0F) {
+            g2.setPaint(outlinePaint);
+            g2.setStroke(new BasicStroke(outlineStroke));
+            g2.draw(nodeShape);
+        }
     }
 
     /**
@@ -178,6 +200,12 @@ public class NodeShapePainter extends NodePainter {
         firePainterChanged();
     }
 
+    public void setOutline(final float outlineStroke, final Paint outlinePaint) {
+        this.outlineStroke = outlineStroke;
+        this.outlinePaint = outlinePaint;
+        firePainterChanged();
+    }
+
     private Shape createNodeShape(Node node, double x, double y) {
 
         double size = maxSize;
@@ -241,8 +269,14 @@ public class NodeShapePainter extends NodePainter {
     private ScaleType scaleType = ScaleType.WIDTH;
     private String sizeAttribute = null;
 
+    private boolean external = true;
+    private boolean internal = true;
+
     private Decorator colourDecorator = null;
     private ContinuousScale sizeScale = null;
 
+    private float outlineStroke = 0.5f;
+    private Paint outlinePaint = Color.black;
+
     private TreePane treePane;
 }
