@@ -1,3 +1,23 @@
+/*
+ * RectilinearTreeLayout.java
+ *
+ * Copyright (C) 2006-2014 Andrew Rambaut
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
+
 package figtree.treeviewer.treelayouts;
 
 import jebl.evolution.graphs.Node;
@@ -9,7 +29,13 @@ import java.util.List;
 
 /**
  * @author Andrew Rambaut
- * @version $Id: RectilinearTreeLayout.java 819 2007-10-22 14:42:58Z rambaut $
+ * @version $Id$
+ *
+ * $HeadURL$
+ *
+ * $LastChangedBy$
+ * $LastChangedDate$
+ * $LastChangedRevision$
  */
 public class RectilinearTreeLayout extends AbstractTreeLayout {
 
@@ -59,9 +85,6 @@ public class RectilinearTreeLayout extends AbstractTreeLayout {
 
     public Shape getAxisLine(double height) {
         double x = height;
-        if (isAxisReversed()) {
-            x = maxXPosition - x;
-        }
         double y1 = 0.0;
         double y2 = 1.0;
         return new Line2D.Double(x, y1, x, y2);
@@ -69,9 +92,6 @@ public class RectilinearTreeLayout extends AbstractTreeLayout {
 
     public Shape getHeightArea(double height1, double height2) {
         double x = height1;
-        if (isAxisReversed()) {
-            x = maxXPosition - x;
-        }
         double y = 0.0;
         double w = Math.abs(height2 - height1);
         double h = 1.0;
@@ -151,11 +171,11 @@ public class RectilinearTreeLayout extends AbstractTreeLayout {
 
         Point2D nodePoint;
 
-        if (!tree.isExternal(node)) {
+        if (hilightAttributeName != null && node.getAttribute(hilightAttributeName) != null) {
+            constructHilight(tree, node, xParent, xPosition, cache);
+        }
 
-            if (hilightAttributeName != null && node.getAttribute(hilightAttributeName) != null) {
-                constructHilight(tree, node, xParent, xPosition, cache);
-            }
+        if (!tree.isExternal(node)) {
 
             if (collapsedAttributeName != null && node.getAttribute(collapsedAttributeName) != null) {
                 nodePoint = constructCollapsedNode(tree, node, xPosition, cache);
